# FlightGear mobileJoystick

[PyPI](https://pypi.org/project/fg-mobileJoystick/)

## Introduction
A simple web app,
enabling users to control FlightGear with mobile devices,
providing a low-cost alternative to joysticks.



## Install
requirements: python, python-pip
```bash
$ pip install fg-mobileJoystick
```
Start FlightGear with `--native-ctrls=socket,out,30,localhost,5503,udp --native-ctrls=socket,in,30,localhost,5504,udp`

```bash
$ mobileJoystick
```

Mobile browser, visit `<your IP>:5000/`


## Contact
- Email: GordonZhang11 _at_ outlook _dot_ com
- FlightGear Forum: GZhang
